# coding: utf-8

"""
    TrueLayer Resource API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1.0
    Contact: rienafairefr@gmail.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import truelayer
from truelayer.models.api_response_me import APIResponseMe  # noqa: E501
from truelayer.rest import ApiException

class TestAPIResponseMe(unittest.TestCase):
    """APIResponseMe unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test APIResponseMe
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = truelayer.models.api_response_me.APIResponseMe()  # noqa: E501
        if include_optional :
            return APIResponseMe(
                results = [
                    truelayer.models.me.Me(
                        client_id = '0', 
                        credentials_id = '0', 
                        provider = truelayer.models.provider_info.ProviderInfo(
                            display_name = '0', 
                            logo_uri = '0', 
                            provider_id = '0', ), 
                        provider_id = '0', )
                    ], 
                results_uri = '0', 
                status = 'Queued', 
                task_id = '0'
            )
        else :
            return APIResponseMe(
        )

    def testAPIResponseMe(self):
        """Test APIResponseMe"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
