# coding: utf-8

"""
    TrueLayer Resource API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1.0
    Contact: rienafairefr@gmail.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import truelayer
from truelayer.models.api_response_info import APIResponseInfo  # noqa: E501
from truelayer.rest import ApiException

class TestAPIResponseInfo(unittest.TestCase):
    """APIResponseInfo unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test APIResponseInfo
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = truelayer.models.api_response_info.APIResponseInfo()  # noqa: E501
        if include_optional :
            return APIResponseInfo(
                results = [
                    truelayer.models.info.Info(
                        addresses = [
                            truelayer.models.address_info.AddressInfo(
                                address = '0', 
                                city = '0', 
                                country = '0', 
                                state = '0', 
                                zip = '0', )
                            ], 
                        date_of_birth = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        emails = [
                            '0'
                            ], 
                        full_name = '0', 
                        phones = [
                            '0'
                            ], 
                        update_timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ], 
                results_uri = '0', 
                status = 'Queued', 
                task_id = '0'
            )
        else :
            return APIResponseInfo(
        )

    def testAPIResponseInfo(self):
        """Test APIResponseInfo"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
