# coding: utf-8

"""
    TrueLayer Resource API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1.0
    Contact: rienafairefr@gmail.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import truelayer
from truelayer.models.card import Card  # noqa: E501
from truelayer.rest import ApiException

class TestCard(unittest.TestCase):
    """Card unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test Card
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = truelayer.models.card.Card()  # noqa: E501
        if include_optional :
            return Card(
                account_id = '0', 
                card_network = '0', 
                card_type = '0', 
                currency = '0', 
                display_name = '0', 
                name_on_card = '0', 
                partial_card_number = '0', 
                provider = truelayer.models.provider_info.ProviderInfo(
                    display_name = '0', 
                    logo_uri = '0', 
                    provider_id = '0', ), 
                update_timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                valid_from = '0', 
                valid_to = '0'
            )
        else :
            return Card(
        )

    def testCard(self):
        """Test Card"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
