# coding: utf-8

"""
    TrueLayer Authtentication

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import truelayer.auth
from truelayer.auth.api.default_api import DefaultApi  # noqa: E501
from truelayer.auth.rest import ApiException


class TestDefaultApi(unittest.TestCase):
    """DefaultApi unit test stubs"""

    def setUp(self):
        self.api = truelayer.auth.api.default_api.DefaultApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_exchange_code(self):
        """Test case for exchange_code

        """
        pass


if __name__ == '__main__':
    unittest.main()
