# coding: utf-8

"""
    TrueLayer Resource API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1.0
    Contact: rienafairefr@gmail.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

import marshmallow
from marshmallow import Schema, validates, ValidationError, post_load, missing

import truelayer
import truelayer.fields
from truelayer.configuration import Configuration


"""
CodegenModel{parent='null', parentSchema='null', interfaces=null, allParents=null, parentModel=null, interfaceModels=null, children=null, anyOf=[], oneOf=[], allOf=[], name='APIResponseCardTransaction', classname='APIResponseCardTransaction', title='null', description='null', classVarName='api_response_card_transaction', modelJson='{
  "type" : "object",
  "properties" : {
    "results" : {
      "type" : "array",
      "items" : {
        "$ref" : "#/components/schemas/CardTransaction"
      }
    },
    "results_uri" : {
      "type" : "string"
    },
    "status" : {
      "type" : "string",
      "enum" : [ "Queued", "Running", "Succeeded", "Failed" ]
    },
    "task_id" : {
      "type" : "string"
    }
  },
  "example" : {
    "task_id" : "task_id",
    "results" : [ {
      "transaction_id" : "transaction_id",
      "amount" : 0.8008281904610115,
      "balance" : {
        "current" : 6.027456183070403,
        "update_timestamp" : "2000-01-23T04:56:07.000+00:00",
        "available" : 0.8008281904610115,
        "currency" : "currency"
      },
      "meta" : {
        "key" : "meta"
      },
      "description" : "description",
      "currency" : "currency",
      "transaction_type" : "transaction_type",
      "timestamp" : "2000-01-23T04:56:07.000+00:00"
    }, {
      "transaction_id" : "transaction_id",
      "amount" : 0.8008281904610115,
      "balance" : {
        "current" : 6.027456183070403,
        "update_timestamp" : "2000-01-23T04:56:07.000+00:00",
        "available" : 0.8008281904610115,
        "currency" : "currency"
      },
      "meta" : {
        "key" : "meta"
      },
      "description" : "description",
      "currency" : "currency",
      "transaction_type" : "transaction_type",
      "timestamp" : "2000-01-23T04:56:07.000+00:00"
    } ],
    "results_uri" : "results_uri",
    "status" : "Queued"
  }
}', dataType='object', xmlPrefix='null', xmlNamespace='null', xmlName='null', classFilename='api_response_card_transaction', unescapedDescription='null', discriminator=null, defaultValue='null', arrayModelType='null', isAlias=false, isString=false, isInteger=false, isLong=false, isNumber=false, isNumeric=false, isFloat=false, isDouble=false, vars=[CodegenProperty{openApiType='array', baseName='results', complexType='CardTransaction', getter='getResults', setter='setResults', description='null', dataType='list[CardTransaction]', datatypeWithEnum='list[CardTransaction]', dataFormat='null', name='results', min='null', max='null', defaultValue='null', defaultValueWithParam=' = data.results;', baseType='list', containerType='array', title='null', unescapedDescription='null', maxLength=null, minLength=null, pattern='null', example='[
                    truelayer.models.card_transaction.CardTransaction(
                        amount = 1.337, 
                        balance = truelayer.models.balance.Balance(
                            available = 1.337, 
                            currency = '0', 
                            current = 1.337, 
                            update_timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                        currency = '0', 
                        description = '0', 
                        meta = {
                            'key' : '0'
                            }, 
                        timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        transaction_id = '0', 
                        transaction_type = '0', )
                    ]', jsonSchema='{
  "type" : "array",
  "items" : {
    "$ref" : "#/components/schemas/CardTransaction"
  }
}', minimum='null', maximum='null', exclusiveMinimum=false, exclusiveMaximum=false, hasMore=true, required=false, deprecated=false, secondaryParam=false, hasMoreNonReadOnly=false, isPrimitiveType=false, isModel=false, isContainer=true, isString=false, isNumeric=false, isInteger=false, isLong=false, isNumber=false, isFloat=false, isDouble=false, isByteArray=false, isBinary=false, isFile=false, isBoolean=false, isDate=false, isDateTime=false, isUuid=false, isUri=false, isEmail=false, isFreeFormObject=false, isListContainer=true, isMapContainer=false, isEnum=false, isReadOnly=false, isWriteOnly=false, isNullable=false, isSelfReference=false, isCircularReference=false, _enum=null, allowableValues=null, items=CodegenProperty{openApiType='CardTransaction', baseName='results', complexType='CardTransaction', getter='getResults', setter='setResults', description='null', dataType='CardTransaction', datatypeWithEnum='CardTransaction', dataFormat='null', name='results', min='null', max='null', defaultValue='null', defaultValueWithParam=' = data.results;', baseType='CardTransaction', containerType='null', title='null', unescapedDescription='null', maxLength=null, minLength=null, pattern='null', example='truelayer.models.card_transaction.CardTransaction(
                    amount = 1.337, 
                    balance = truelayer.models.balance.Balance(
                        available = 1.337, 
                        currency = '0', 
                        current = 1.337, 
                        update_timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                    currency = '0', 
                    description = '0', 
                    meta = {
                        'key' : '0'
                        }, 
                    timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    transaction_id = '0', 
                    transaction_type = '0', )', jsonSchema='{
  "$ref" : "#/components/schemas/CardTransaction"
}', minimum='null', maximum='null', exclusiveMinimum=false, exclusiveMaximum=false, hasMore=false, required=false, deprecated=false, secondaryParam=false, hasMoreNonReadOnly=false, isPrimitiveType=false, isModel=true, isContainer=false, isString=false, isNumeric=false, isInteger=false, isLong=false, isNumber=false, isFloat=false, isDouble=false, isByteArray=false, isBinary=false, isFile=false, isBoolean=false, isDate=false, isDateTime=false, isUuid=false, isUri=false, isEmail=false, isFreeFormObject=false, isListContainer=false, isMapContainer=false, isEnum=false, isReadOnly=false, isWriteOnly=false, isNullable=false, isSelfReference=false, isCircularReference=false, _enum=null, allowableValues=null, items=null, mostInnerItems=null, vendorExtensions={}, hasValidation=false, isInherited=false, discriminatorValue='null', nameInCamelCase='Results', nameInSnakeCase='RESULTS', enumName='null', maxItems=null, minItems=null, maxProperties=null, minProperties=null, uniqueItems=false, multipleOf=null, isXmlAttribute=false, xmlPrefix='null', xmlName='null', xmlNamespace='null', isXmlWrapped=false}, mostInnerItems=CodegenProperty{openApiType='CardTransaction', baseName='results', complexType='CardTransaction', getter='getResults', setter='setResults', description='null', dataType='CardTransaction', datatypeWithEnum='CardTransaction', dataFormat='null', name='results', min='null', max='null', defaultValue='null', defaultValueWithParam=' = data.results;', baseType='CardTransaction', containerType='null', title='null', unescapedDescription='null', maxLength=null, minLength=null, pattern='null', example='truelayer.models.card_transaction.CardTransaction(
                    amount = 1.337, 
                    balance = truelayer.models.balance.Balance(
                        available = 1.337, 
                        currency = '0', 
                        current = 1.337, 
                        update_timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                    currency = '0', 
                    description = '0', 
                    meta = {
                        'key' : '0'
                        }, 
                    timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    transaction_id = '0', 
                    transaction_type = '0', )', jsonSchema='{
  "$ref" : "#/components/schemas/CardTransaction"
}', minimum='null', maximum='null', exclusiveMinimum=false, exclusiveMaximum=false, hasMore=false, required=false, deprecated=false, secondaryParam=false, hasMoreNonReadOnly=false, isPrimitiveType=false, isModel=true, isContainer=false, isString=false, isNumeric=false, isInteger=false, isLong=false, isNumber=false, isFloat=false, isDouble=false, isByteArray=false, isBinary=false, isFile=false, isBoolean=false, isDate=false, isDateTime=false, isUuid=false, isUri=false, isEmail=false, isFreeFormObject=false, isListContainer=false, isMapContainer=false, isEnum=false, isReadOnly=false, isWriteOnly=false, isNullable=false, isSelfReference=false, isCircularReference=false, _enum=null, allowableValues=null, items=null, mostInnerItems=null, vendorExtensions={}, hasValidation=false, isInherited=false, discriminatorValue='null', nameInCamelCase='Results', nameInSnakeCase='RESULTS', enumName='null', maxItems=null, minItems=null, maxProperties=null, minProperties=null, uniqueItems=false, multipleOf=null, isXmlAttribute=false, xmlPrefix='null', xmlName='null', xmlNamespace='null', isXmlWrapped=false}, vendorExtensions={}, hasValidation=false, isInherited=false, discriminatorValue='null', nameInCamelCase='Results', nameInSnakeCase='RESULTS', enumName='null', maxItems=null, minItems=null, maxProperties=null, minProperties=null, uniqueItems=false, multipleOf=null, isXmlAttribute=false, xmlPrefix='null', xmlName='null', xmlNamespace='null', isXmlWrapped=false}, CodegenProperty{openApiType='string', baseName='results_uri', complexType='null', getter='getResultsUri', setter='setResultsUri', description='null', dataType='str', datatypeWithEnum='str', dataFormat='null', name='results_uri', min='null', max='null', defaultValue='null', defaultValueWithParam=' = data.results_uri;', baseType='str', containerType='null', title='null', unescapedDescription='null', maxLength=null, minLength=null, pattern='null', example=''0'', jsonSchema='{
  "type" : "string"
}', minimum='null', maximum='null', exclusiveMinimum=false, exclusiveMaximum=false, hasMore=true, required=false, deprecated=false, secondaryParam=false, hasMoreNonReadOnly=false, isPrimitiveType=true, isModel=false, isContainer=false, isString=true, isNumeric=false, isInteger=false, isLong=false, isNumber=false, isFloat=false, isDouble=false, isByteArray=false, isBinary=false, isFile=false, isBoolean=false, isDate=false, isDateTime=false, isUuid=false, isUri=false, isEmail=false, isFreeFormObject=false, isListContainer=false, isMapContainer=false, isEnum=false, isReadOnly=false, isWriteOnly=false, isNullable=false, isSelfReference=false, isCircularReference=false, _enum=null, allowableValues=null, items=null, mostInnerItems=null, vendorExtensions={}, hasValidation=false, isInherited=false, discriminatorValue='null', nameInCamelCase='ResultsUri', nameInSnakeCase='RESULTS_URI', enumName='null', maxItems=null, minItems=null, maxProperties=null, minProperties=null, uniqueItems=false, multipleOf=null, isXmlAttribute=false, xmlPrefix='null', xmlName='null', xmlNamespace='null', isXmlWrapped=false}, CodegenProperty{openApiType='string', baseName='status', complexType='null', getter='getStatus', setter='setStatus', description='null', dataType='str', datatypeWithEnum='StatusEnum', dataFormat='null', name='status', min='null', max='null', defaultValue='null', defaultValueWithParam=' = data.status;', baseType='str', containerType='null', title='null', unescapedDescription='null', maxLength=null, minLength=null, pattern='null', example=''Queued'', jsonSchema='{
  "type" : "string",
  "enum" : [ "Queued", "Running", "Succeeded", "Failed" ]
}', minimum='null', maximum='null', exclusiveMinimum=false, exclusiveMaximum=false, hasMore=true, required=false, deprecated=false, secondaryParam=false, hasMoreNonReadOnly=false, isPrimitiveType=true, isModel=false, isContainer=false, isString=true, isNumeric=false, isInteger=false, isLong=false, isNumber=false, isFloat=false, isDouble=false, isByteArray=false, isBinary=false, isFile=false, isBoolean=false, isDate=false, isDateTime=false, isUuid=false, isUri=false, isEmail=false, isFreeFormObject=false, isListContainer=false, isMapContainer=false, isEnum=true, isReadOnly=false, isWriteOnly=false, isNullable=false, isSelfReference=false, isCircularReference=false, _enum=[Queued, Running, Succeeded, Failed], allowableValues={enumVars=[{name=QUEUED, isString=false, value="Queued"}, {name=RUNNING, isString=false, value="Running"}, {name=SUCCEEDED, isString=false, value="Succeeded"}, {name=FAILED, isString=false, value="Failed"}], values=[Queued, Running, Succeeded, Failed]}, items=null, mostInnerItems=null, vendorExtensions={}, hasValidation=false, isInherited=false, discriminatorValue='null', nameInCamelCase='Status', nameInSnakeCase='STATUS', enumName='StatusEnum', maxItems=null, minItems=null, maxProperties=null, minProperties=null, uniqueItems=false, multipleOf=null, isXmlAttribute=false, xmlPrefix='null', xmlName='null', xmlNamespace='null', isXmlWrapped=false}, CodegenProperty{openApiType='string', baseName='task_id', complexType='null', getter='getTaskId', setter='setTaskId', description='null', dataType='str', datatypeWithEnum='str', dataFormat='null', name='task_id', min='null', max='null', defaultValue='null', defaultValueWithParam=' = data.task_id;', baseType='str', containerType='null', title='null', unescapedDescription='null', maxLength=null, minLength=null, pattern='null', example=''0'', jsonSchema='{
  "type" : "string"
}', minimum='null', maximum='null', exclusiveMinimum=false, exclusiveMaximum=false, hasMore=false, required=false, deprecated=false, secondaryParam=false, hasMoreNonReadOnly=false, isPrimitiveType=true, isModel=false, isContainer=false, isString=true, isNumeric=false, isInteger=false, isLong=false, isNumber=false, isFloat=false, isDouble=false, isByteArray=false, isBinary=false, isFile=false, isBoolean=false, isDate=false, isDateTime=false, isUuid=false, isUri=false, isEmail=false, isFreeFormObject=false, isListContainer=false, isMapContainer=false, isEnum=false, isReadOnly=false, isWriteOnly=false, isNullable=false, isSelfReference=false, isCircularReference=false, _enum=null, allowableValues=null, items=null, mostInnerItems=null, vendorExtensions={}, hasValidation=false, isInherited=false, discriminatorValue='null', nameInCamelCase='TaskId', nameInSnakeCase='TASK_ID', enumName='null', maxItems=null, minItems=null, maxProperties=null, minProperties=null, uniqueItems=false, multipleOf=null, isXmlAttribute=false, xmlPrefix='null', xmlName='null', xmlNamespace='null', isXmlWrapped=false}], allVars=[CodegenProperty{openApiType='array', baseName='results', complexType='CardTransaction', getter='getResults', setter='setResults', description='null', dataType='list[CardTransaction]', datatypeWithEnum='list[CardTransaction]', dataFormat='null', name='results', min='null', max='null', defaultValue='null', defaultValueWithParam=' = data.results;', baseType='list', containerType='array', title='null', unescapedDescription='null', maxLength=null, minLength=null, pattern='null', example='[
                    truelayer.models.card_transaction.CardTransaction(
                        amount = 1.337, 
                        balance = truelayer.models.balance.Balance(
                            available = 1.337, 
                            currency = '0', 
                            current = 1.337, 
                            update_timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                        currency = '0', 
                        description = '0', 
                        meta = {
                            'key' : '0'
                            }, 
                        timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        transaction_id = '0', 
                        transaction_type = '0', )
                    ]', jsonSchema='{
  "type" : "array",
  "items" : {
    "$ref" : "#/components/schemas/CardTransaction"
  }
}', minimum='null', maximum='null', exclusiveMinimum=false, exclusiveMaximum=false, hasMore=true, required=false, deprecated=false, secondaryParam=false, hasMoreNonReadOnly=false, isPrimitiveType=false, isModel=false, isContainer=true, isString=false, isNumeric=false, isInteger=false, isLong=false, isNumber=false, isFloat=false, isDouble=false, isByteArray=false, isBinary=false, isFile=false, isBoolean=false, isDate=false, isDateTime=false, isUuid=false, isUri=false, isEmail=false, isFreeFormObject=false, isListContainer=true, isMapContainer=false, isEnum=false, isReadOnly=false, isWriteOnly=false, isNullable=false, isSelfReference=false, isCircularReference=false, _enum=null, allowableValues=null, items=CodegenProperty{openApiType='CardTransaction', baseName='results', complexType='CardTransaction', getter='getResults', setter='setResults', description='null', dataType='CardTransaction', datatypeWithEnum='CardTransaction', dataFormat='null', name='results', min='null', max='null', defaultValue='null', defaultValueWithParam=' = data.results;', baseType='CardTransaction', containerType='null', title='null', unescapedDescription='null', maxLength=null, minLength=null, pattern='null', example='truelayer.models.card_transaction.CardTransaction(
                    amount = 1.337, 
                    balance = truelayer.models.balance.Balance(
                        available = 1.337, 
                        currency = '0', 
                        current = 1.337, 
                        update_timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                    currency = '0', 
                    description = '0', 
                    meta = {
                        'key' : '0'
                        }, 
                    timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    transaction_id = '0', 
                    transaction_type = '0', )', jsonSchema='{
  "$ref" : "#/components/schemas/CardTransaction"
}', minimum='null', maximum='null', exclusiveMinimum=false, exclusiveMaximum=false, hasMore=false, required=false, deprecated=false, secondaryParam=false, hasMoreNonReadOnly=false, isPrimitiveType=false, isModel=true, isContainer=false, isString=false, isNumeric=false, isInteger=false, isLong=false, isNumber=false, isFloat=false, isDouble=false, isByteArray=false, isBinary=false, isFile=false, isBoolean=false, isDate=false, isDateTime=false, isUuid=false, isUri=false, isEmail=false, isFreeFormObject=false, isListContainer=false, isMapContainer=false, isEnum=false, isReadOnly=false, isWriteOnly=false, isNullable=false, isSelfReference=false, isCircularReference=false, _enum=null, allowableValues=null, items=null, mostInnerItems=null, vendorExtensions={}, hasValidation=false, isInherited=false, discriminatorValue='null', nameInCamelCase='Results', nameInSnakeCase='RESULTS', enumName='null', maxItems=null, minItems=null, maxProperties=null, minProperties=null, uniqueItems=false, multipleOf=null, isXmlAttribute=false, xmlPrefix='null', xmlName='null', xmlNamespace='null', isXmlWrapped=false}, mostInnerItems=CodegenProperty{openApiType='CardTransaction', baseName='results', complexType='CardTransaction', getter='getResults', setter='setResults', description='null', dataType='CardTransaction', datatypeWithEnum='CardTransaction', dataFormat='null', name='results', min='null', max='null', defaultValue='null', defaultValueWithParam=' = data.results;', baseType='CardTransaction', containerType='null', title='null', unescapedDescription='null', maxLength=null, minLength=null, pattern='null', example='truelayer.models.card_transaction.CardTransaction(
                    amount = 1.337, 
                    balance = truelayer.models.balance.Balance(
                        available = 1.337, 
                        currency = '0', 
                        current = 1.337, 
                        update_timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                    currency = '0', 
                    description = '0', 
                    meta = {
                        'key' : '0'
                        }, 
                    timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    transaction_id = '0', 
                    transaction_type = '0', )', jsonSchema='{
  "$ref" : "#/components/schemas/CardTransaction"
}', minimum='null', maximum='null', exclusiveMinimum=false, exclusiveMaximum=false, hasMore=false, required=false, deprecated=false, secondaryParam=false, hasMoreNonReadOnly=false, isPrimitiveType=false, isModel=true, isContainer=false, isString=false, isNumeric=false, isInteger=false, isLong=false, isNumber=false, isFloat=false, isDouble=false, isByteArray=false, isBinary=false, isFile=false, isBoolean=false, isDate=false, isDateTime=false, isUuid=false, isUri=false, isEmail=false, isFreeFormObject=false, isListContainer=false, isMapContainer=false, isEnum=false, isReadOnly=false, isWriteOnly=false, isNullable=false, isSelfReference=false, isCircularReference=false, _enum=null, allowableValues=null, items=null, mostInnerItems=null, vendorExtensions={}, hasValidation=false, isInherited=false, discriminatorValue='null', nameInCamelCase='Results', nameInSnakeCase='RESULTS', enumName='null', maxItems=null, minItems=null, maxProperties=null, minProperties=null, uniqueItems=false, multipleOf=null, isXmlAttribute=false, xmlPrefix='null', xmlName='null', xmlNamespace='null', isXmlWrapped=false}, vendorExtensions={}, hasValidation=false, isInherited=false, discriminatorValue='null', nameInCamelCase='Results', nameInSnakeCase='RESULTS', enumName='null', maxItems=null, minItems=null, maxProperties=null, minProperties=null, uniqueItems=false, multipleOf=null, isXmlAttribute=false, xmlPrefix='null', xmlName='null', xmlNamespace='null', isXmlWrapped=false}, CodegenProperty{openApiType='string', baseName='results_uri', complexType='null', getter='getResultsUri', setter='setResultsUri', description='null', dataType='str', datatypeWithEnum='str', dataFormat='null', name='results_uri', min='null', max='null', defaultValue='null', defaultValueWithParam=' = data.results_uri;', baseType='str', containerType='null', title='null', unescapedDescription='null', maxLength=null, minLength=null, pattern='null', example=''0'', jsonSchema='{
  "type" : "string"
}', minimum='null', maximum='null', exclusiveMinimum=false, exclusiveMaximum=false, hasMore=true, required=false, deprecated=false, secondaryParam=false, hasMoreNonReadOnly=false, isPrimitiveType=true, isModel=false, isContainer=false, isString=true, isNumeric=false, isInteger=false, isLong=false, isNumber=false, isFloat=false, isDouble=false, isByteArray=false, isBinary=false, isFile=false, isBoolean=false, isDate=false, isDateTime=false, isUuid=false, isUri=false, isEmail=false, isFreeFormObject=false, isListContainer=false, isMapContainer=false, isEnum=false, isReadOnly=false, isWriteOnly=false, isNullable=false, isSelfReference=false, isCircularReference=false, _enum=null, allowableValues=null, items=null, mostInnerItems=null, vendorExtensions={}, hasValidation=false, isInherited=false, discriminatorValue='null', nameInCamelCase='ResultsUri', nameInSnakeCase='RESULTS_URI', enumName='null', maxItems=null, minItems=null, maxProperties=null, minProperties=null, uniqueItems=false, multipleOf=null, isXmlAttribute=false, xmlPrefix='null', xmlName='null', xmlNamespace='null', isXmlWrapped=false}, CodegenProperty{openApiType='string', baseName='status', complexType='null', getter='getStatus', setter='setStatus', description='null', dataType='str', datatypeWithEnum='StatusEnum', dataFormat='null', name='status', min='null', max='null', defaultValue='null', defaultValueWithParam=' = data.status;', baseType='str', containerType='null', title='null', unescapedDescription='null', maxLength=null, minLength=null, pattern='null', example=''Queued'', jsonSchema='{
  "type" : "string",
  "enum" : [ "Queued", "Running", "Succeeded", "Failed" ]
}', minimum='null', maximum='null', exclusiveMinimum=false, exclusiveMaximum=false, hasMore=true, required=false, deprecated=false, secondaryParam=false, hasMoreNonReadOnly=false, isPrimitiveType=true, isModel=false, isContainer=false, isString=true, isNumeric=false, isInteger=false, isLong=false, isNumber=false, isFloat=false, isDouble=false, isByteArray=false, isBinary=false, isFile=false, isBoolean=false, isDate=false, isDateTime=false, isUuid=false, isUri=false, isEmail=false, isFreeFormObject=false, isListContainer=false, isMapContainer=false, isEnum=true, isReadOnly=false, isWriteOnly=false, isNullable=false, isSelfReference=false, isCircularReference=false, _enum=[Queued, Running, Succeeded, Failed], allowableValues={enumVars=[{name=QUEUED, isString=false, value="Queued"}, {name=RUNNING, isString=false, value="Running"}, {name=SUCCEEDED, isString=false, value="Succeeded"}, {name=FAILED, isString=false, value="Failed"}], values=[Queued, Running, Succeeded, Failed]}, items=null, mostInnerItems=null, vendorExtensions={}, hasValidation=false, isInherited=false, discriminatorValue='null', nameInCamelCase='Status', nameInSnakeCase='STATUS', enumName='StatusEnum', maxItems=null, minItems=null, maxProperties=null, minProperties=null, uniqueItems=false, multipleOf=null, isXmlAttribute=false, xmlPrefix='null', xmlName='null', xmlNamespace='null', isXmlWrapped=false}, CodegenProperty{openApiType='string', baseName='task_id', complexType='null', getter='getTaskId', setter='setTaskId', description='null', dataType='str', datatypeWithEnum='str', dataFormat='null', name='task_id', min='null', max='null', defaultValue='null', defaultValueWithParam=' = data.task_id;', baseType='str', containerType='null', title='null', unescapedDescription='null', maxLength=null, minLength=null, pattern='null', example=''0'', jsonSchema='{
  "type" : "string"
}', minimum='null', maximum='null', exclusiveMinimum=false, exclusiveMaximum=false, hasMore=false, required=false, deprecated=false, secondaryParam=false, hasMoreNonReadOnly=false, isPrimitiveType=true, isModel=false, isContainer=false, isString=true, isNumeric=false, isInteger=false, isLong=false, isNumber=false, isFloat=false, isDouble=false, isByteArray=false, isBinary=false, isFile=false, isBoolean=false, isDate=false, isDateTime=false, isUuid=false, isUri=false, isEmail=false, isFreeFormObject=false, isListContainer=false, isMapContainer=false, isEnum=false, isReadOnly=false, isWriteOnly=false, isNullable=false, isSelfReference=false, isCircularReference=false, _enum=null, allowableValues=null, items=null, mostInnerItems=null, vendorExtensions={}, hasValidation=false, isInherited=false, discriminatorValue='null', nameInCamelCase='TaskId', nameInSnakeCase='TASK_ID', enumName='null', maxItems=null, minItems=null, maxProperties=null, minProperties=null, uniqueItems=false, multipleOf=null, isXmlAttribute=false, xmlPrefix='null', xmlName='null', xmlNamespace='null', isXmlWrapped=false}], requiredVars=[], optionalVars=[CodegenProperty{openApiType='array', baseName='results', complexType='CardTransaction', getter='getResults', setter='setResults', description='null', dataType='list[CardTransaction]', datatypeWithEnum='list[CardTransaction]', dataFormat='null', name='results', min='null', max='null', defaultValue='null', defaultValueWithParam=' = data.results;', baseType='list', containerType='array', title='null', unescapedDescription='null', maxLength=null, minLength=null, pattern='null', example='[
                    truelayer.models.card_transaction.CardTransaction(
                        amount = 1.337, 
                        balance = truelayer.models.balance.Balance(
                            available = 1.337, 
                            currency = '0', 
                            current = 1.337, 
                            update_timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                        currency = '0', 
                        description = '0', 
                        meta = {
                            'key' : '0'
                            }, 
                        timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        transaction_id = '0', 
                        transaction_type = '0', )
                    ]', jsonSchema='{
  "type" : "array",
  "items" : {
    "$ref" : "#/components/schemas/CardTransaction"
  }
}', minimum='null', maximum='null', exclusiveMinimum=false, exclusiveMaximum=false, hasMore=true, required=false, deprecated=false, secondaryParam=false, hasMoreNonReadOnly=false, isPrimitiveType=false, isModel=false, isContainer=true, isString=false, isNumeric=false, isInteger=false, isLong=false, isNumber=false, isFloat=false, isDouble=false, isByteArray=false, isBinary=false, isFile=false, isBoolean=false, isDate=false, isDateTime=false, isUuid=false, isUri=false, isEmail=false, isFreeFormObject=false, isListContainer=true, isMapContainer=false, isEnum=false, isReadOnly=false, isWriteOnly=false, isNullable=false, isSelfReference=false, isCircularReference=false, _enum=null, allowableValues=null, items=CodegenProperty{openApiType='CardTransaction', baseName='results', complexType='CardTransaction', getter='getResults', setter='setResults', description='null', dataType='CardTransaction', datatypeWithEnum='CardTransaction', dataFormat='null', name='results', min='null', max='null', defaultValue='null', defaultValueWithParam=' = data.results;', baseType='CardTransaction', containerType='null', title='null', unescapedDescription='null', maxLength=null, minLength=null, pattern='null', example='truelayer.models.card_transaction.CardTransaction(
                    amount = 1.337, 
                    balance = truelayer.models.balance.Balance(
                        available = 1.337, 
                        currency = '0', 
                        current = 1.337, 
                        update_timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                    currency = '0', 
                    description = '0', 
                    meta = {
                        'key' : '0'
                        }, 
                    timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    transaction_id = '0', 
                    transaction_type = '0', )', jsonSchema='{
  "$ref" : "#/components/schemas/CardTransaction"
}', minimum='null', maximum='null', exclusiveMinimum=false, exclusiveMaximum=false, hasMore=false, required=false, deprecated=false, secondaryParam=false, hasMoreNonReadOnly=false, isPrimitiveType=false, isModel=true, isContainer=false, isString=false, isNumeric=false, isInteger=false, isLong=false, isNumber=false, isFloat=false, isDouble=false, isByteArray=false, isBinary=false, isFile=false, isBoolean=false, isDate=false, isDateTime=false, isUuid=false, isUri=false, isEmail=false, isFreeFormObject=false, isListContainer=false, isMapContainer=false, isEnum=false, isReadOnly=false, isWriteOnly=false, isNullable=false, isSelfReference=false, isCircularReference=false, _enum=null, allowableValues=null, items=null, mostInnerItems=null, vendorExtensions={}, hasValidation=false, isInherited=false, discriminatorValue='null', nameInCamelCase='Results', nameInSnakeCase='RESULTS', enumName='null', maxItems=null, minItems=null, maxProperties=null, minProperties=null, uniqueItems=false, multipleOf=null, isXmlAttribute=false, xmlPrefix='null', xmlName='null', xmlNamespace='null', isXmlWrapped=false}, mostInnerItems=CodegenProperty{openApiType='CardTransaction', baseName='results', complexType='CardTransaction', getter='getResults', setter='setResults', description='null', dataType='CardTransaction', datatypeWithEnum='CardTransaction', dataFormat='null', name='results', min='null', max='null', defaultValue='null', defaultValueWithParam=' = data.results;', baseType='CardTransaction', containerType='null', title='null', unescapedDescription='null', maxLength=null, minLength=null, pattern='null', example='truelayer.models.card_transaction.CardTransaction(
                    amount = 1.337, 
                    balance = truelayer.models.balance.Balance(
                        available = 1.337, 
                        currency = '0', 
                        current = 1.337, 
                        update_timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                    currency = '0', 
                    description = '0', 
                    meta = {
                        'key' : '0'
                        }, 
                    timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    transaction_id = '0', 
                    transaction_type = '0', )', jsonSchema='{
  "$ref" : "#/components/schemas/CardTransaction"
}', minimum='null', maximum='null', exclusiveMinimum=false, exclusiveMaximum=false, hasMore=false, required=false, deprecated=false, secondaryParam=false, hasMoreNonReadOnly=false, isPrimitiveType=false, isModel=true, isContainer=false, isString=false, isNumeric=false, isInteger=false, isLong=false, isNumber=false, isFloat=false, isDouble=false, isByteArray=false, isBinary=false, isFile=false, isBoolean=false, isDate=false, isDateTime=false, isUuid=false, isUri=false, isEmail=false, isFreeFormObject=false, isListContainer=false, isMapContainer=false, isEnum=false, isReadOnly=false, isWriteOnly=false, isNullable=false, isSelfReference=false, isCircularReference=false, _enum=null, allowableValues=null, items=null, mostInnerItems=null, vendorExtensions={}, hasValidation=false, isInherited=false, discriminatorValue='null', nameInCamelCase='Results', nameInSnakeCase='RESULTS', enumName='null', maxItems=null, minItems=null, maxProperties=null, minProperties=null, uniqueItems=false, multipleOf=null, isXmlAttribute=false, xmlPrefix='null', xmlName='null', xmlNamespace='null', isXmlWrapped=false}, vendorExtensions={}, hasValidation=false, isInherited=false, discriminatorValue='null', nameInCamelCase='Results', nameInSnakeCase='RESULTS', enumName='null', maxItems=null, minItems=null, maxProperties=null, minProperties=null, uniqueItems=false, multipleOf=null, isXmlAttribute=false, xmlPrefix='null', xmlName='null', xmlNamespace='null', isXmlWrapped=false}, CodegenProperty{openApiType='string', baseName='results_uri', complexType='null', getter='getResultsUri', setter='setResultsUri', description='null', dataType='str', datatypeWithEnum='str', dataFormat='null', name='results_uri', min='null', max='null', defaultValue='null', defaultValueWithParam=' = data.results_uri;', baseType='str', containerType='null', title='null', unescapedDescription='null', maxLength=null, minLength=null, pattern='null', example=''0'', jsonSchema='{
  "type" : "string"
}', minimum='null', maximum='null', exclusiveMinimum=false, exclusiveMaximum=false, hasMore=true, required=false, deprecated=false, secondaryParam=false, hasMoreNonReadOnly=false, isPrimitiveType=true, isModel=false, isContainer=false, isString=true, isNumeric=false, isInteger=false, isLong=false, isNumber=false, isFloat=false, isDouble=false, isByteArray=false, isBinary=false, isFile=false, isBoolean=false, isDate=false, isDateTime=false, isUuid=false, isUri=false, isEmail=false, isFreeFormObject=false, isListContainer=false, isMapContainer=false, isEnum=false, isReadOnly=false, isWriteOnly=false, isNullable=false, isSelfReference=false, isCircularReference=false, _enum=null, allowableValues=null, items=null, mostInnerItems=null, vendorExtensions={}, hasValidation=false, isInherited=false, discriminatorValue='null', nameInCamelCase='ResultsUri', nameInSnakeCase='RESULTS_URI', enumName='null', maxItems=null, minItems=null, maxProperties=null, minProperties=null, uniqueItems=false, multipleOf=null, isXmlAttribute=false, xmlPrefix='null', xmlName='null', xmlNamespace='null', isXmlWrapped=false}, CodegenProperty{openApiType='string', baseName='status', complexType='null', getter='getStatus', setter='setStatus', description='null', dataType='str', datatypeWithEnum='StatusEnum', dataFormat='null', name='status', min='null', max='null', defaultValue='null', defaultValueWithParam=' = data.status;', baseType='str', containerType='null', title='null', unescapedDescription='null', maxLength=null, minLength=null, pattern='null', example=''Queued'', jsonSchema='{
  "type" : "string",
  "enum" : [ "Queued", "Running", "Succeeded", "Failed" ]
}', minimum='null', maximum='null', exclusiveMinimum=false, exclusiveMaximum=false, hasMore=true, required=false, deprecated=false, secondaryParam=false, hasMoreNonReadOnly=false, isPrimitiveType=true, isModel=false, isContainer=false, isString=true, isNumeric=false, isInteger=false, isLong=false, isNumber=false, isFloat=false, isDouble=false, isByteArray=false, isBinary=false, isFile=false, isBoolean=false, isDate=false, isDateTime=false, isUuid=false, isUri=false, isEmail=false, isFreeFormObject=false, isListContainer=false, isMapContainer=false, isEnum=true, isReadOnly=false, isWriteOnly=false, isNullable=false, isSelfReference=false, isCircularReference=false, _enum=[Queued, Running, Succeeded, Failed], allowableValues={enumVars=[{name=QUEUED, isString=false, value="Queued"}, {name=RUNNING, isString=false, value="Running"}, {name=SUCCEEDED, isString=false, value="Succeeded"}, {name=FAILED, isString=false, value="Failed"}], values=[Queued, Running, Succeeded, Failed]}, items=null, mostInnerItems=null, vendorExtensions={}, hasValidation=false, isInherited=false, discriminatorValue='null', nameInCamelCase='Status', nameInSnakeCase='STATUS', enumName='StatusEnum', maxItems=null, minItems=null, maxProperties=null, minProperties=null, uniqueItems=false, multipleOf=null, isXmlAttribute=false, xmlPrefix='null', xmlName='null', xmlNamespace='null', isXmlWrapped=false}, CodegenProperty{openApiType='string', baseName='task_id', complexType='null', getter='getTaskId', setter='setTaskId', description='null', dataType='str', datatypeWithEnum='str', dataFormat='null', name='task_id', min='null', max='null', defaultValue='null', defaultValueWithParam=' = data.task_id;', baseType='str', containerType='null', title='null', unescapedDescription='null', maxLength=null, minLength=null, pattern='null', example=''0'', jsonSchema='{
  "type" : "string"
}', minimum='null', maximum='null', exclusiveMinimum=false, exclusiveMaximum=false, hasMore=false, required=false, deprecated=false, secondaryParam=false, hasMoreNonReadOnly=false, isPrimitiveType=true, isModel=false, isContainer=false, isString=true, isNumeric=false, isInteger=false, isLong=false, isNumber=false, isFloat=false, isDouble=false, isByteArray=false, isBinary=false, isFile=false, isBoolean=false, isDate=false, isDateTime=false, isUuid=false, isUri=false, isEmail=false, isFreeFormObject=false, isListContainer=false, isMapContainer=false, isEnum=false, isReadOnly=false, isWriteOnly=false, isNullable=false, isSelfReference=false, isCircularReference=false, _enum=null, allowableValues=null, items=null, mostInnerItems=null, vendorExtensions={}, hasValidation=false, isInherited=false, discriminatorValue='null', nameInCamelCase='TaskId', nameInSnakeCase='TASK_ID', enumName='null', maxItems=null, minItems=null, maxProperties=null, minProperties=null, uniqueItems=false, multipleOf=null, isXmlAttribute=false, xmlPrefix='null', xmlName='null', xmlNamespace='null', isXmlWrapped=false}], readOnlyVars=[], readWriteVars=[CodegenProperty{openApiType='array', baseName='results', complexType='CardTransaction', getter='getResults', setter='setResults', description='null', dataType='list[CardTransaction]', datatypeWithEnum='list[CardTransaction]', dataFormat='null', name='results', min='null', max='null', defaultValue='null', defaultValueWithParam=' = data.results;', baseType='list', containerType='array', title='null', unescapedDescription='null', maxLength=null, minLength=null, pattern='null', example='[
                    truelayer.models.card_transaction.CardTransaction(
                        amount = 1.337, 
                        balance = truelayer.models.balance.Balance(
                            available = 1.337, 
                            currency = '0', 
                            current = 1.337, 
                            update_timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                        currency = '0', 
                        description = '0', 
                        meta = {
                            'key' : '0'
                            }, 
                        timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        transaction_id = '0', 
                        transaction_type = '0', )
                    ]', jsonSchema='{
  "type" : "array",
  "items" : {
    "$ref" : "#/components/schemas/CardTransaction"
  }
}', minimum='null', maximum='null', exclusiveMinimum=false, exclusiveMaximum=false, hasMore=true, required=false, deprecated=false, secondaryParam=false, hasMoreNonReadOnly=false, isPrimitiveType=false, isModel=false, isContainer=true, isString=false, isNumeric=false, isInteger=false, isLong=false, isNumber=false, isFloat=false, isDouble=false, isByteArray=false, isBinary=false, isFile=false, isBoolean=false, isDate=false, isDateTime=false, isUuid=false, isUri=false, isEmail=false, isFreeFormObject=false, isListContainer=true, isMapContainer=false, isEnum=false, isReadOnly=false, isWriteOnly=false, isNullable=false, isSelfReference=false, isCircularReference=false, _enum=null, allowableValues=null, items=CodegenProperty{openApiType='CardTransaction', baseName='results', complexType='CardTransaction', getter='getResults', setter='setResults', description='null', dataType='CardTransaction', datatypeWithEnum='CardTransaction', dataFormat='null', name='results', min='null', max='null', defaultValue='null', defaultValueWithParam=' = data.results;', baseType='CardTransaction', containerType='null', title='null', unescapedDescription='null', maxLength=null, minLength=null, pattern='null', example='truelayer.models.card_transaction.CardTransaction(
                    amount = 1.337, 
                    balance = truelayer.models.balance.Balance(
                        available = 1.337, 
                        currency = '0', 
                        current = 1.337, 
                        update_timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                    currency = '0', 
                    description = '0', 
                    meta = {
                        'key' : '0'
                        }, 
                    timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    transaction_id = '0', 
                    transaction_type = '0', )', jsonSchema='{
  "$ref" : "#/components/schemas/CardTransaction"
}', minimum='null', maximum='null', exclusiveMinimum=false, exclusiveMaximum=false, hasMore=false, required=false, deprecated=false, secondaryParam=false, hasMoreNonReadOnly=false, isPrimitiveType=false, isModel=true, isContainer=false, isString=false, isNumeric=false, isInteger=false, isLong=false, isNumber=false, isFloat=false, isDouble=false, isByteArray=false, isBinary=false, isFile=false, isBoolean=false, isDate=false, isDateTime=false, isUuid=false, isUri=false, isEmail=false, isFreeFormObject=false, isListContainer=false, isMapContainer=false, isEnum=false, isReadOnly=false, isWriteOnly=false, isNullable=false, isSelfReference=false, isCircularReference=false, _enum=null, allowableValues=null, items=null, mostInnerItems=null, vendorExtensions={}, hasValidation=false, isInherited=false, discriminatorValue='null', nameInCamelCase='Results', nameInSnakeCase='RESULTS', enumName='null', maxItems=null, minItems=null, maxProperties=null, minProperties=null, uniqueItems=false, multipleOf=null, isXmlAttribute=false, xmlPrefix='null', xmlName='null', xmlNamespace='null', isXmlWrapped=false}, mostInnerItems=CodegenProperty{openApiType='CardTransaction', baseName='results', complexType='CardTransaction', getter='getResults', setter='setResults', description='null', dataType='CardTransaction', datatypeWithEnum='CardTransaction', dataFormat='null', name='results', min='null', max='null', defaultValue='null', defaultValueWithParam=' = data.results;', baseType='CardTransaction', containerType='null', title='null', unescapedDescription='null', maxLength=null, minLength=null, pattern='null', example='truelayer.models.card_transaction.CardTransaction(
                    amount = 1.337, 
                    balance = truelayer.models.balance.Balance(
                        available = 1.337, 
                        currency = '0', 
                        current = 1.337, 
                        update_timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                    currency = '0', 
                    description = '0', 
                    meta = {
                        'key' : '0'
                        }, 
                    timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    transaction_id = '0', 
                    transaction_type = '0', )', jsonSchema='{
  "$ref" : "#/components/schemas/CardTransaction"
}', minimum='null', maximum='null', exclusiveMinimum=false, exclusiveMaximum=false, hasMore=false, required=false, deprecated=false, secondaryParam=false, hasMoreNonReadOnly=false, isPrimitiveType=false, isModel=true, isContainer=false, isString=false, isNumeric=false, isInteger=false, isLong=false, isNumber=false, isFloat=false, isDouble=false, isByteArray=false, isBinary=false, isFile=false, isBoolean=false, isDate=false, isDateTime=false, isUuid=false, isUri=false, isEmail=false, isFreeFormObject=false, isListContainer=false, isMapContainer=false, isEnum=false, isReadOnly=false, isWriteOnly=false, isNullable=false, isSelfReference=false, isCircularReference=false, _enum=null, allowableValues=null, items=null, mostInnerItems=null, vendorExtensions={}, hasValidation=false, isInherited=false, discriminatorValue='null', nameInCamelCase='Results', nameInSnakeCase='RESULTS', enumName='null', maxItems=null, minItems=null, maxProperties=null, minProperties=null, uniqueItems=false, multipleOf=null, isXmlAttribute=false, xmlPrefix='null', xmlName='null', xmlNamespace='null', isXmlWrapped=false}, vendorExtensions={}, hasValidation=false, isInherited=false, discriminatorValue='null', nameInCamelCase='Results', nameInSnakeCase='RESULTS', enumName='null', maxItems=null, minItems=null, maxProperties=null, minProperties=null, uniqueItems=false, multipleOf=null, isXmlAttribute=false, xmlPrefix='null', xmlName='null', xmlNamespace='null', isXmlWrapped=false}, CodegenProperty{openApiType='string', baseName='results_uri', complexType='null', getter='getResultsUri', setter='setResultsUri', description='null', dataType='str', datatypeWithEnum='str', dataFormat='null', name='results_uri', min='null', max='null', defaultValue='null', defaultValueWithParam=' = data.results_uri;', baseType='str', containerType='null', title='null', unescapedDescription='null', maxLength=null, minLength=null, pattern='null', example=''0'', jsonSchema='{
  "type" : "string"
}', minimum='null', maximum='null', exclusiveMinimum=false, exclusiveMaximum=false, hasMore=true, required=false, deprecated=false, secondaryParam=false, hasMoreNonReadOnly=false, isPrimitiveType=true, isModel=false, isContainer=false, isString=true, isNumeric=false, isInteger=false, isLong=false, isNumber=false, isFloat=false, isDouble=false, isByteArray=false, isBinary=false, isFile=false, isBoolean=false, isDate=false, isDateTime=false, isUuid=false, isUri=false, isEmail=false, isFreeFormObject=false, isListContainer=false, isMapContainer=false, isEnum=false, isReadOnly=false, isWriteOnly=false, isNullable=false, isSelfReference=false, isCircularReference=false, _enum=null, allowableValues=null, items=null, mostInnerItems=null, vendorExtensions={}, hasValidation=false, isInherited=false, discriminatorValue='null', nameInCamelCase='ResultsUri', nameInSnakeCase='RESULTS_URI', enumName='null', maxItems=null, minItems=null, maxProperties=null, minProperties=null, uniqueItems=false, multipleOf=null, isXmlAttribute=false, xmlPrefix='null', xmlName='null', xmlNamespace='null', isXmlWrapped=false}, CodegenProperty{openApiType='string', baseName='status', complexType='null', getter='getStatus', setter='setStatus', description='null', dataType='str', datatypeWithEnum='StatusEnum', dataFormat='null', name='status', min='null', max='null', defaultValue='null', defaultValueWithParam=' = data.status;', baseType='str', containerType='null', title='null', unescapedDescription='null', maxLength=null, minLength=null, pattern='null', example=''Queued'', jsonSchema='{
  "type" : "string",
  "enum" : [ "Queued", "Running", "Succeeded", "Failed" ]
}', minimum='null', maximum='null', exclusiveMinimum=false, exclusiveMaximum=false, hasMore=true, required=false, deprecated=false, secondaryParam=false, hasMoreNonReadOnly=false, isPrimitiveType=true, isModel=false, isContainer=false, isString=true, isNumeric=false, isInteger=false, isLong=false, isNumber=false, isFloat=false, isDouble=false, isByteArray=false, isBinary=false, isFile=false, isBoolean=false, isDate=false, isDateTime=false, isUuid=false, isUri=false, isEmail=false, isFreeFormObject=false, isListContainer=false, isMapContainer=false, isEnum=true, isReadOnly=false, isWriteOnly=false, isNullable=false, isSelfReference=false, isCircularReference=false, _enum=[Queued, Running, Succeeded, Failed], allowableValues={enumVars=[{name=QUEUED, isString=false, value="Queued"}, {name=RUNNING, isString=false, value="Running"}, {name=SUCCEEDED, isString=false, value="Succeeded"}, {name=FAILED, isString=false, value="Failed"}], values=[Queued, Running, Succeeded, Failed]}, items=null, mostInnerItems=null, vendorExtensions={}, hasValidation=false, isInherited=false, discriminatorValue='null', nameInCamelCase='Status', nameInSnakeCase='STATUS', enumName='StatusEnum', maxItems=null, minItems=null, maxProperties=null, minProperties=null, uniqueItems=false, multipleOf=null, isXmlAttribute=false, xmlPrefix='null', xmlName='null', xmlNamespace='null', isXmlWrapped=false}, CodegenProperty{openApiType='string', baseName='task_id', complexType='null', getter='getTaskId', setter='setTaskId', description='null', dataType='str', datatypeWithEnum='str', dataFormat='null', name='task_id', min='null', max='null', defaultValue='null', defaultValueWithParam=' = data.task_id;', baseType='str', containerType='null', title='null', unescapedDescription='null', maxLength=null, minLength=null, pattern='null', example=''0'', jsonSchema='{
  "type" : "string"
}', minimum='null', maximum='null', exclusiveMinimum=false, exclusiveMaximum=false, hasMore=false, required=false, deprecated=false, secondaryParam=false, hasMoreNonReadOnly=false, isPrimitiveType=true, isModel=false, isContainer=false, isString=true, isNumeric=false, isInteger=false, isLong=false, isNumber=false, isFloat=false, isDouble=false, isByteArray=false, isBinary=false, isFile=false, isBoolean=false, isDate=false, isDateTime=false, isUuid=false, isUri=false, isEmail=false, isFreeFormObject=false, isListContainer=false, isMapContainer=false, isEnum=false, isReadOnly=false, isWriteOnly=false, isNullable=false, isSelfReference=false, isCircularReference=false, _enum=null, allowableValues=null, items=null, mostInnerItems=null, vendorExtensions={}, hasValidation=false, isInherited=false, discriminatorValue='null', nameInCamelCase='TaskId', nameInSnakeCase='TASK_ID', enumName='null', maxItems=null, minItems=null, maxProperties=null, minProperties=null, uniqueItems=false, multipleOf=null, isXmlAttribute=false, xmlPrefix='null', xmlName='null', xmlNamespace='null', isXmlWrapped=false}], parentVars=[], allowableValues=null, mandatory=[], allMandatory=[], imports=[CardTransaction], hasVars=true, emptyVars=false, hasMoreModels=false, hasEnums=true, isEnum=false, isNullable=false, hasRequired=false, hasOptional=true, isArrayModel=false, hasChildren=false, isMapModel=false, hasOnlyReadOnly=false, externalDocumentation=null, vendorExtensions={}, additionalPropertiesType='null', maxProperties=null, minProperties=null, uniqueItems=false, maxItems=null, minItems=null, maxLength=null, minLength=null, exclusiveMinimum=false, exclusiveMaximum=false, minimum='null', maximum='null', pattern='null', multipleOf='null'}
"""


class APIResponseCardTransactionSchema(Schema):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    results = marshmallow.fields.List(truelayer.fields.Nested('CardTransaction')('CardTransactionSchema', )
,)

    results_uri = marshmallow.fields.String()

    status = marshmallow.fields.String()

    task_id = marshmallow.fields.String()

    @validates("results")
    def validates_results(self, results):
        pass

    @validates("results_uri")
    def validates_results_uri(self, results_uri):
        pass

    @validates("status")
    def validates_status(self, status):
        allowed_values = ["Queued", "Running", "Succeeded", "Failed"]  # noqa: E501
        if status not in allowed_values:  # noqa: E501
            raise ValidationError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )
        pass

    @validates("task_id")
    def validates_task_id(self, task_id):
        pass

    @post_load
    def post_load(self, data, **kwargs):
        config = Configuration()
        config.client_side_validation = False
        return APIResponseCardTransaction(local_vars_configuration=config, **data)


class APIResponseCardTransaction(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'results': 'list[CardTransaction]',
        'results_uri': 'str',
        'status': 'str',
        'task_id': 'str'
    }

    attribute_map = {
        'results': 'results',
        'results_uri': 'results_uri',
        'status': 'status',
        'task_id': 'task_id'
    }

    def __init__(self, results=missing, results_uri=missing, status=missing, task_id=missing, local_vars_configuration=None):  # noqa: E501
        """APIResponseCardTransaction - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self.discriminator = None
        if self.local_vars_configuration.client_side_validation:
            validated = APIResponseCardTransactionSchema().load({
                'results': results,
                'results_uri': results_uri,
                'status': status,
                'task_id': task_id
            })
            self.results = validated.results
            self.results_uri = validated.results_uri
            self.status = validated.status
            self.task_id = validated.task_id
        else:
            self.results = results
            self.results_uri = results_uri
            self.status = status
            self.task_id = task_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        return APIResponseCardTransactionSchema().dump(self)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, APIResponseCardTransaction):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, APIResponseCardTransaction):
            return True

        return self.to_dict() != other.to_dict()
