# coding: utf-8

"""
    TrueLayer Resource API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1.0
    Contact: rienafairefr@gmail.com
    Generated by: https://openapi-generator.tech
"""


from setuptools import setup, find_packages  # noqa: H301

NAME = "pytruelayer"
VERSION = "0.1.0"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = ["urllib3 >= 1.15", "six >= 1.10", "certifi", "python-dateutil", "marshmallow"]

setup(
    name=NAME,
    version=VERSION,
    description="TrueLayer Resource API",
    author="TrueLayer.com",
    author_email="rienafairefr@gmail.com",
    url="",
    keywords=["OpenAPI", "OpenAPI-Generator", "TrueLayer Resource API"],
    install_requires=REQUIRES,
    packages=find_packages(exclude=["test", "tests"]),
    include_package_data=True,
    
    long_description_content_type="text/markdown",
    long_description="""\
    This is pytruelayer, an autogenerated package to access Truelayer Auth & Data API

    https://www.truelayer.com

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)
    """
)
